@@ -88,7 +88,7 @@ sshzd1 <- function(formula,type=NULL,data=list(),alpha=1.4,
     term <- mkterm(mf,type)
     ## Generate random
     if (!is.null(random)) {
-        if (class(random)=="formula") random <- mkran(random,data)
+        if (inherits(random,"formula")) random <- mkran(random,data)
     }
     ## Generate Gauss-Legendre quadrature
     nmesh <- 200
@@ -428,12 +428,14 @@ msphzd1 <- function(s,r,id.wk,Nobs,cnt,int.s,int.r,rho,random,prec,maxiter,alpha
         cv <- (zz$min-cv.shift)/cv.scale
     }
     else {
+        mn0 <- log.la0-6
+        mx0 <- log.la0+6
         repeat {
-            mn <- la-1
-            mx <- la+1
-            if (mx>log.la0+6) break
+            mn <- max(la-1,mn0)
+            mx <- min(la+1,mx0)
             zz <- nlm0(cv.s,c(mn,mx))
-            if (min(zz$est-mn,mx-zz$est)>=1e-3) break
+            if ((min(zz$est-mn,mx-zz$est)>=1e-1)||
+                (min(zz$est-mn0,mx0-zz$est)<1e-1)) break
             else la <- zz$est
         }
         cv <- zz$min
@@ -531,12 +533,14 @@ msphzd1 <- function(s,r,id.wk,Nobs,cnt,int.s,int.r,rho,random,prec,maxiter,alpha
         cv <- (zz$min-cv.shift)/cv.scale
     }
     else {
+        mn0 <- log.la0-6
+        mx0 <- log.la0+6
         repeat {
-            mn <- la-1
-            mx <- la+1
-            if (mx>log.la0+6) break
+            mn <- max(la-1,mn0)
+            mx <- min(la+1,mx0)
             zz <- nlm0(cv.s,c(mn,mx))
-            if (min(zz$est-mn,mx-zz$est)>=1e-3) break
+            if ((min(zz$est-mn,mx-zz$est)>=1e-1)||
+                (min(zz$est-mn0,mx0-zz$est)<1e-1)) break
             else la <- zz$est
         }
         cv <- zz$min
